Tutorials — QTI's python SDK for IOT connected camera 0.0 documentation

# Tutorials

This tutorials will help you in understanding how to use the APIs supported by the SDK to create different connected camera applications.

- Basic tutorial 1: Live preview

- Basic tutorial 2: Live preview with recording

- Basic tutorial 3: Live preview with snapshot

- Basic tutorial 4: Live preview with analytics and overlay

- Basic tutorial 5: Live preview with analytics, overlay and snapshot